AsConfig

Trait AsConfig 

pub trait AsConfig {
    // Required method
    fn to_config(self) -> Config;
}
If your type can be converted to Config, you should implement the AsConfig trait

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> AsConfig for T
where T: Into<Config>,

AsConfig is automatically implemented for all Into trait objects